Assets class
This file is automatically generated. DO NOT EDIT, all your changes would be lost.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- animationBle → const String
- animationBluetooth → const String
- animationBrokenHeart → const String
- animationBrokenHeart2 → const String
- animationCheck → const String
- animationChecked → const String
- animationCheckedGreenNew → const String
- animationCheckGreen → const String
- animationGasStation → const String
- animationGasStationTest → const String
- animationLoveEmoji → const String
- animationNfc → const String
- animationNozel → const String
- animationSmileEmoji → const String
- arefRuqaaArefRuqaaBold → const String
- arefRuqaaArefRuqaaRegular → const String
- iconsAppIcon → const String
- iconsArrow → const String
- iconsForwardArrow → const String